@@ -10,7 +10,8 @@ from pytorch_grad_cam import GradCAM, \
                              AblationCAM, \
                              XGradCAM, \
                              EigenCAM, \
-                             EigenGradCAM
+                             EigenGradCAM, \
+                             LayerCAM    
 
 from pytorch_grad_cam import GuidedBackpropReLUModel
 from pytorch_grad_cam.utils.image import show_cam_on_image, \
@@ -30,10 +31,12 @@ def get_args():
                         help='Reduce noise by taking the first principle componenet'
                         'of cam_weights*activations')
     parser.add_argument('--method', type=str, default='gradcam',
-                        choices=['gradcam', 'gradcam++', 'scorecam', 'xgradcam',
-                                 'ablationcam', 'eigencam', 'eigengradcam'],
+                        choices=['gradcam', 'gradcam++', 
+                                 'scorecam', 'xgradcam',
+                                 'ablationcam', 'eigencam', 
+                                 'eigengradcam', 'layercam'],
                         help='Can be gradcam/gradcam++/scorecam/xgradcam'
-                             '/ablationcam/eigencam/eigengradcam')
+                             '/ablationcam/eigencam/eigengradcam/layercam')
 
     args = parser.parse_args()
     args.use_cuda = args.use_cuda and torch.cuda.is_available()
@@ -61,7 +64,8 @@ if __name__ == '__main__':
          "ablationcam": AblationCAM,
          "xgradcam": XGradCAM,
          "eigencam": EigenCAM,
-         "eigengradcam": EigenGradCAM}
+         "eigengradcam": EigenGradCAM,
+         "layercam": LayerCAM}
 
     model = models.resnet50(pretrained=True)
 
@@ -99,7 +103,10 @@ if __name__ == '__main__':
     # Here grayscale_cam has only one image in the batch
     grayscale_cam = grayscale_cam[0, :]
 
-    cam_image = show_cam_on_image(rgb_img, grayscale_cam)
+    cam_image = show_cam_on_image(rgb_img, grayscale_cam, use_rgb=True)
+
+    # cam_image is RGB encoded whereas "cv2.imwrite" requires BGR encoding.
+    cam_image = cv2.cvtColor(cam_image, cv2.COLOR_RGB2BGR)
 
     gb_model = GuidedBackpropReLUModel(model=model, use_cuda=args.use_cuda)
     gb = gb_model(input_tensor, target_category=target_category)
@@ -110,4 +117,4 @@ if __name__ == '__main__':
 
     cv2.imwrite(f'{args.method}_cam.jpg', cam_image)
     cv2.imwrite(f'{args.method}_gb.jpg', gb)
-    cv2.imwrite(f'{args.method}_cam_gb.jpg', cam_gb)
+    cv2.imwrite(f'{args.method}_cam_gb.jpg', cam_gb)
\ No newline at end of file
